==> haskell-wai-cors-0.2.7-482.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-cors
version:              0.2.7
visibility:           public
id:                   wai-cors-0.2.7-El0NDX5Zn1eHjnX2LhYzcA
key:                  wai-cors-0.2.7-El0NDX5Zn1eHjnX2LhYzcA
license:              MIT
copyright:
    (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
    (c) 2014 AlephCloud Systems, Inc.

maintainer:           Lars Kuhtz <lakuhtz@gmail.com>
author:               Lars Kuhtz <lakuhtz@gmail.com>
homepage:             https://github.com/larskuhtz/wai-cors
synopsis:             CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.

category:             HTTP, Network, Web, Wai
abi:                  9b42e002995c08c9d9ca1deafeb2c48c
exposed:              True
exposed-modules:      Network.Wai.Middleware.Cors
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-cors-0.2.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-cors-0.2.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-cors
hs-libraries:         HSwai-cors-0.2.7-El0NDX5Zn1eHjnX2LhYzcA
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    base-unicode-symbols-0.2.4.2-LX7whyw4bmGCqzVQbQIjtq
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS mtl-2.3.1
    transformers-0.6.1.0 wai-3.2.4-DrO6v22Rmno6pXUhKStSuj

haddock-interfaces:   /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html:         /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-cors-0.2.7-483-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-cors
version:              0.2.7
visibility:           public
id:                   wai-cors-0.2.7-JB1BAwklGsc8BcDTxFL8JZ
key:                  wai-cors-0.2.7-JB1BAwklGsc8BcDTxFL8JZ
license:              MIT
copyright:
    (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
    (c) 2014 AlephCloud Systems, Inc.

maintainer:           Lars Kuhtz <lakuhtz@gmail.com>
author:               Lars Kuhtz <lakuhtz@gmail.com>
homepage:             https://github.com/larskuhtz/wai-cors
synopsis:             CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.

category:             HTTP, Network, Web, Wai
abi:                  3e8eb9ec137d980d54a9ad3a7e2f6902
exposed:              True
exposed-modules:      Network.Wai.Middleware.Cors
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-cors-0.2.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-cors-0.2.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-cors
hs-libraries:         HSwai-cors-0.2.7-JB1BAwklGsc8BcDTxFL8JZ
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base-unicode-symbols-0.2.4.2-LX7whyw4bmGCqzVQbQIjtq
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt mtl-2.3.1
    transformers-0.6.1.0 wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63

haddock-interfaces:   /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html:         /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
